@@ -8,10 +8,22 @@ use SQL::ReservedWords::PostgreSQL();
 
 use Rose::DB;
 
-our $VERSION = '0.738';
+our $VERSION = '0.753';
 
 our $Debug = 0;
 
+#
+# Object data
+#
+
+use Rose::Object::MakeMethods::Generic
+(
+  'scalar' =>
+  [
+    qw(sslmode service options)
+  ],
+);
+
 #
 # Object methods
 #
@@ -23,13 +35,14 @@ sub build_dsn
   my %info;
 
   $info{'dbname'} = $args{'db'} || $args{'database'};
-  $info{'host'}   = $args{'host'};
-  $info{'port'}   = $args{'port'};
+
+  @info{qw(host port options service sslmode)} =
+    @args{qw(host port options service sslmode)};
 
   return
     "dbi:Pg:" . 
     join(';', map { "$_=$info{$_}" } grep { defined $info{$_} }
-              qw(dbname host port));
+              qw(dbname host port options service sslmode));
 }
 
 sub dbi_driver { 'Pg' }
@@ -369,7 +382,6 @@ sub refine_dbi_column_info
     $col_info->{'COLUMN_SIZE'} = undef;
   }
 
-
   # Pg does not populate COLUMN_SIZE correctly for bit fields, so
   # we have to extract the number of bits from pg_type.
   if($col_info->{'pg_type'} =~ /^bit\((\d+)\)$/)
@@ -392,6 +404,14 @@ sub refine_dbi_column_info
     }
   }
 
+  # Treat custom types that look like enums as enums
+  if(ref $col_info->{'pg_enum_values'} && @{$col_info->{'pg_enum_values'}})
+  {
+    $col_info->{'TYPE_NAME'} = 'enum';
+    $col_info->{'RDBO_ENUM_VALUES'} = $col_info->{'pg_enum_values'};
+    $col_info->{'RDBO_DB_TYPE'} = $col_info->{'pg_type'};
+  }
+
   # We currently treat all arrays the same, regardless of what they are 
   # arrays of: integer, character, float, etc.  So we covert TYPE_NAMEs
   # like 'integer[]' into 'array'
@@ -583,6 +603,10 @@ Returns the value of this attribute in the L<dbh|Rose::DB/dbh>, if one exists, o
 
 See the L<DBD::Pg|DBD::Pg/pg_enable_utf8> documentation to learn more about this attribute.
 
+=item B<sslmode [MODE]>
+
+Get or set the SSL mode of the connection.  Valid values for MODE are C<disable>, C<allow>, C<prefer>, and C<require>.  This attribute is used to build the L<DBI> L<dsn|Rose::DB/dsn>.  Setting it has no effect until the next L<connect|Rose::DB/connect>ion.  See the L<DBD::Pg|DBD::Pg/connect> documentation to learn more about this attribute.
+
 =back
 
 =head2 Value Parsing and Formatting
